# parquet_performance
> Measure the performance of parquet files using pandas


This file will become your README and also the index of your documentation.

## Install

`pip install parquet_performance`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


